/*----------------------------------------------------------------------------
 *      RL-ARM - RTX
 *----------------------------------------------------------------------------
 *      Name:    Ex2_RTX_events.C
 *      Purpose: RTX example program
 *----------------------------------------------------------------------------
 *      This code is part of the RealView Run-Time Library.
 *      Copyright (c) 2012 KEIL - An ARM Company. All rights reserved.
 *---------------------------------------------------------------------------*/

#include "cmsis_os.h"
#include "stm32f0xx.h"
#include "stm32f0_discovery.h"
#include "LED.h"
#include "Button.h"


/*----------------------------------------------------------------------------
  User Variables
 *---------------------------------------------------------------------------*/
int	LED_0_toggle_counter = 0;		/* used to count number of toggles for LED 0 */
int	LED_1_toggle_counter = 0;		/* used to count number of toggles for LED 1 */
int button_counter = 0;					/* used to count number of button presses    */

/*----------------------------------------------------------------------------
  Thread IDs
 *---------------------------------------------------------------------------*/	
osThreadId T_led_0;
osThreadId T_led_1;


/*----------------------------------------------------------------------------
  Forward Reference
 *---------------------------------------------------------------------------*/	
void led_0 (void const *argument);
void led_1 (void const *argument);
void button_control (void const *argument);

/*----------------------------------------------------------------------------
  Thread Definitions
 *---------------------------------------------------------------------------*/	
osThreadDef(led_0, osPriorityNormal, 1, 0);
osThreadDef(led_1, osPriorityNormal, 1, 0);
osThreadDef(xxx, xxx, xxx, xxx);




/*----------------------------------------------------------------------------
 *   Button_IRQHandler : takes action in application when button IRQ occurs
 *---------------------------------------------------------------------------*/
void Button_IRQHandler (void) {
																				// send an event to the Button Task
	}


/*----------------------------------------------------------------------------
  Thread 1 'led_0': Toggle LED 0
 *---------------------------------------------------------------------------*/
void led_0 (void const *argument) {
  for (;;) {
    LED_On(0);                          /* Turn LED 0 On                     */
    osDelay(500);												/* Delay running task for 500 ticks	 */
		LED_Off(0);													/* Turn LED 0 On                     */
		osDelay(500);												/* Delay running task for 500 ticks	 */
		LED_0_toggle_counter++;							/* Increment LED 0 toggle counter		 */
		}
}

/*----------------------------------------------------------------------------
  Thread 2 'led_1': Toggle LED 1
 *---------------------------------------------------------------------------*/
void led_1 (void const *argument) {
  for (;;) {
    LED_On(1);                          /* Turn LED On                       */
    osDelay(250);												/* Delay running task for 250 ticks	 */
		LED_Off(1);													/* Turn LED 0 On                     */
		osDelay(250);												/* Delay running task for 250 ticks	 */
		LED_1_toggle_counter++;							/* Increment LED 1 toggle counter		 */
		}
}


/*----------------------------------------------------------------------------
  Thread 3 'button_control': Responds to user input on hardware button
 *---------------------------------------------------------------------------*/
void button_control (void const *argument) {
  for (;;) {
    osDelay(100);															// debounce button
		EnableButtonIRQ();												// enable the IRQ for the button
																							// wait (forever) for Flag 0x0001
																							// clear flag 0x0001
		button_counter++;
		}
}




/*----------------------------------------------------------------------------
  Main: Initialize and start RTX Kernel
 *---------------------------------------------------------------------------*/
int main (void) {
	
	/* Initialise various hardware elements used in project */
	SystemInit();  				// CMSIS SystemInit clocks and PLLs
	Button_Init();				// Configure External Interrupt on PA0
	LED_Init ();					// Initialise LED's on F0 discovery kit
	
	
	/* Create the threads for the RTOS to run */
	T_led_1 					= osThreadCreate(osThread(led_1), NULL);
	T_led_0 					= osThreadCreate(osThread(led_0), NULL);
  xxx							 	= osThreadCreate(osThread(xxx), NULL);
	
	osThreadYield();			// Pass runtime to next READY task	
}









